# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/lovely-numpy',
                'doc_host': 'https://xl0.github.io',
                'git_url': 'https://github.com/xl0/lovely-numpy',
                'lib_path': 'lovely_numpy'},
  'syms': { 'lovely_numpy.lo': { 'lovely_numpy.lo.Lo': ('lo.html#lo', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.Lo.__call__': ('lo.html#lo.__call__', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.Lo.__init__': ('lo.html#lo.__init__', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.Lo.__repr__': ('lo.html#lo.__repr__', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.Lo.chans': ('lo.html#lo.chans', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.Lo.deeper': ('lo.html#lo.deeper', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.Lo.p': ('lo.html#lo.p', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.Lo.plt': ('lo.html#lo.plt', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.Lo.rgb': ('lo.html#lo.rgb', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.Lo.v': ('lo.html#lo.v', 'lovely_numpy/lo.py'),
                                 'lovely_numpy.lo.lo': ('lo.html#lo', 'lovely_numpy/lo.py')},
            'lovely_numpy.repr_chans': { 'lovely_numpy.repr_chans.ChanProxy': ('repr_chans.html#chanproxy', 'lovely_numpy/repr_chans.py'),
                                         'lovely_numpy.repr_chans.ChanProxy.__call__': ( 'repr_chans.html#chanproxy.__call__',
                                                                                         'lovely_numpy/repr_chans.py'),
                                         'lovely_numpy.repr_chans.ChanProxy.__init__': ( 'repr_chans.html#chanproxy.__init__',
                                                                                         'lovely_numpy/repr_chans.py'),
                                         'lovely_numpy.repr_chans.ChanProxy._repr_png_': ( 'repr_chans.html#chanproxy._repr_png_',
                                                                                           'lovely_numpy/repr_chans.py'),
                                         'lovely_numpy.repr_chans.ChanProxy.fig': ( 'repr_chans.html#chanproxy.fig',
                                                                                    'lovely_numpy/repr_chans.py'),
                                         'lovely_numpy.repr_chans.chans': ('repr_chans.html#chans', 'lovely_numpy/repr_chans.py'),
                                         'lovely_numpy.repr_chans.fig_chans': ('repr_chans.html#fig_chans', 'lovely_numpy/repr_chans.py')},
            'lovely_numpy.repr_plt': { 'lovely_numpy.repr_plt.PlotProxy': ('repr_plt.html#plotproxy', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.PlotProxy.__call__': ( 'repr_plt.html#plotproxy.__call__',
                                                                                     'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.PlotProxy.__init__': ( 'repr_plt.html#plotproxy.__init__',
                                                                                     'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.PlotProxy._repr_png_': ( 'repr_plt.html#plotproxy._repr_png_',
                                                                                       'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.PlotProxy._repr_svg_': ( 'repr_plt.html#plotproxy._repr_svg_',
                                                                                       'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.PlotProxy.fig': ('repr_plt.html#plotproxy.fig', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.fig_plot': ('repr_plt.html#fig_plot', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.find_xlims': ('repr_plt.html#find_xlims', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.normal_pdf': ('repr_plt.html#normal_pdf', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.plot': ('repr_plt.html#plot', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.plot_histogram': ('repr_plt.html#plot_histogram', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.plot_minmax': ('repr_plt.html#plot_minmax', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.plot_pdf': ('repr_plt.html#plot_pdf', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.plot_sigmas': ('repr_plt.html#plot_sigmas', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.plot_str': ('repr_plt.html#plot_str', 'lovely_numpy/repr_plt.py'),
                                       'lovely_numpy.repr_plt.sample': ('repr_plt.html#sample', 'lovely_numpy/repr_plt.py')},
            'lovely_numpy.repr_rgb': { 'lovely_numpy.repr_rgb.RGBProxy': ('repr_rgb.html#rgbproxy', 'lovely_numpy/repr_rgb.py'),
                                       'lovely_numpy.repr_rgb.RGBProxy.__call__': ( 'repr_rgb.html#rgbproxy.__call__',
                                                                                    'lovely_numpy/repr_rgb.py'),
                                       'lovely_numpy.repr_rgb.RGBProxy.__init__': ( 'repr_rgb.html#rgbproxy.__init__',
                                                                                    'lovely_numpy/repr_rgb.py'),
                                       'lovely_numpy.repr_rgb.RGBProxy._repr_png_': ( 'repr_rgb.html#rgbproxy._repr_png_',
                                                                                      'lovely_numpy/repr_rgb.py'),
                                       'lovely_numpy.repr_rgb.RGBProxy.fig': ('repr_rgb.html#rgbproxy.fig', 'lovely_numpy/repr_rgb.py'),
                                       'lovely_numpy.repr_rgb.fig_rgb': ('repr_rgb.html#fig_rgb', 'lovely_numpy/repr_rgb.py'),
                                       'lovely_numpy.repr_rgb.rgb': ('repr_rgb.html#rgb', 'lovely_numpy/repr_rgb.py')},
            'lovely_numpy.repr_str': { 'lovely_numpy.repr_str.lovely': ('repr_str.html#lovely', 'lovely_numpy/repr_str.py'),
                                       'lovely_numpy.repr_str.plain_repr': ('repr_str.html#plain_repr', 'lovely_numpy/repr_str.py'),
                                       'lovely_numpy.repr_str.short_dtype': ('repr_str.html#short_dtype', 'lovely_numpy/repr_str.py')},
            'lovely_numpy.utils.colormap': { 'lovely_numpy.utils.colormap.InfCmap': ( 'utils.colormap.html#infcmap',
                                                                                      'lovely_numpy/utils/colormap.py'),
                                             'lovely_numpy.utils.colormap.InfCmap.__call__': ( 'utils.colormap.html#infcmap.__call__',
                                                                                               'lovely_numpy/utils/colormap.py'),
                                             'lovely_numpy.utils.colormap.InfCmap.__init__': ( 'utils.colormap.html#infcmap.__init__',
                                                                                               'lovely_numpy/utils/colormap.py'),
                                             'lovely_numpy.utils.colormap.get_cmap': ( 'utils.colormap.html#get_cmap',
                                                                                       'lovely_numpy/utils/colormap.py')},
            'lovely_numpy.utils.config': { 'lovely_numpy.utils.config.Config': ('utils.config.html#config', 'lovely_numpy/utils/config.py'),
                                           'lovely_numpy.utils.config.Config.__init__': ( 'utils.config.html#config.__init__',
                                                                                          'lovely_numpy/utils/config.py'),
                                           'lovely_numpy.utils.config._Default': ( 'utils.config.html#_default',
                                                                                   'lovely_numpy/utils/config.py'),
                                           'lovely_numpy.utils.config._Default.__repr__': ( 'utils.config.html#_default.__repr__',
                                                                                            'lovely_numpy/utils/config.py'),
                                           'lovely_numpy.utils.config.config': ('utils.config.html#config', 'lovely_numpy/utils/config.py'),
                                           'lovely_numpy.utils.config.get_config': ( 'utils.config.html#get_config',
                                                                                     'lovely_numpy/utils/config.py'),
                                           'lovely_numpy.utils.config.set_config': ( 'utils.config.html#set_config',
                                                                                     'lovely_numpy/utils/config.py')},
            'lovely_numpy.utils.pad': { 'lovely_numpy.utils.pad.pad_frame': ('utils.pad.html#pad_frame', 'lovely_numpy/utils/pad.py'),
                                        'lovely_numpy.utils.pad.pad_frame_gutters': ( 'utils.pad.html#pad_frame_gutters',
                                                                                      'lovely_numpy/utils/pad.py')},
            'lovely_numpy.utils.tile2d': { 'lovely_numpy.utils.tile2d.fit_columns': ( 'utils.tile2d.html#fit_columns',
                                                                                      'lovely_numpy/utils/tile2d.py'),
                                           'lovely_numpy.utils.tile2d.hypertile': ( 'utils.tile2d.html#hypertile',
                                                                                    'lovely_numpy/utils/tile2d.py'),
                                           'lovely_numpy.utils.tile2d.tile2d': ( 'utils.tile2d.html#tile2d',
                                                                                 'lovely_numpy/utils/tile2d.py')},
            'lovely_numpy.utils.utils': { 'lovely_numpy.utils.utils.ansi_color': ( 'utils.utils.html#ansi_color',
                                                                                   'lovely_numpy/utils/utils.py'),
                                          'lovely_numpy.utils.utils.history_warning': ( 'utils.utils.html#history_warning',
                                                                                        'lovely_numpy/utils/utils.py'),
                                          'lovely_numpy.utils.utils.np_to_str_common': ( 'utils.utils.html#np_to_str_common',
                                                                                         'lovely_numpy/utils/utils.py'),
                                          'lovely_numpy.utils.utils.plain_repr': ( 'utils.utils.html#plain_repr',
                                                                                   'lovely_numpy/utils/utils.py'),
                                          'lovely_numpy.utils.utils.plain_str': ( 'utils.utils.html#plain_str',
                                                                                  'lovely_numpy/utils/utils.py'),
                                          'lovely_numpy.utils.utils.pretty_str': ( 'utils.utils.html#pretty_str',
                                                                                   'lovely_numpy/utils/utils.py'),
                                          'lovely_numpy.utils.utils.sci_mode': ('utils.utils.html#sci_mode', 'lovely_numpy/utils/utils.py'),
                                          'lovely_numpy.utils.utils.sparse_join': ( 'utils.utils.html#sparse_join',
                                                                                    'lovely_numpy/utils/utils.py')}}}
